@@ -1,9 +1,8 @@
 package Graph::ReadWrite;
-
+$Graph::ReadWrite::VERSION = '2.10';
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '2.07';
 
 1;
 
@@ -21,8 +20,6 @@ modules for a specific format:
 
 =over 4
 
-=back
-
 =item * L<Graph::Reader::Dot> -
 class for reading a Graph instance from Dot format.
 
@@ -44,7 +41,7 @@ class for reading a Graph instance from Dot format.
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/Graph-ReadWrite>
+L<https://github.com/neilb/Graph-ReadWrite>
 
 =head1 AUTHOR
 
