@@ -2,12 +2,12 @@
 # Graph::Writer::VCG - write a directed graph out in VCG format
 #
 package Graph::Writer::VCG;
-
+$Graph::Writer::VCG::VERSION = '2.10';
+use 5.006;
 use strict;
 use warnings;
 
 use parent 'Graph::Writer';
-our $VERSION = '2.07';
 
 #-----------------------------------------------------------------------
 # Attribute type information
@@ -293,10 +293,10 @@ Graph::Writer::VCG - write out directed graph in VCG format
 
   use Graph;
   use Graph::Writer::VCG;
-  
+
   $graph = Graph->new();
   # add edges and nodes to the graph
-  
+
   $writer = Graph::Writer::VCG->new();
   $writer->write_graph($graph, 'mygraph.vcg');
 
@@ -374,6 +374,10 @@ The base-class for Graph::Writer::VCG
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/neilb/Graph-ReadWrite>
+
 =head1 AUTHOR
 
 Neil Bowers E<lt>neil@bowers.comE<gt>
