@@ -2,12 +2,12 @@
 # Graph::Writer::daVinci - write a directed graph out in daVinci format
 #
 package Graph::Writer::daVinci;
-
+$Graph::Writer::daVinci::VERSION = '2.10';
+use 5.006;
 use strict;
 use warnings;
 
 use parent 'Graph::Writer';
-our $VERSION = '2.06';
 
 #-----------------------------------------------------------------------
 # List of valid daVinci attributes for the entire graph, per node,
@@ -182,10 +182,10 @@ Graph::Writer::daVinci - write out directed graph in daVinci format
 
   use Graph;
   use Graph::Writer::daVinci;
-    
+
   $graph = Graph->new();
   # add edges and nodes to the graph
-    
+
   $writer = Graph::Writer::daVinci->new();
   $writer->write_graph($graph, 'mygraph.davinci');
 
@@ -223,7 +223,7 @@ or a filehandle for a previously opened file.
 
 The home page for the daVinci.
 
-=item Graph
+=item L<Graph>
 
 Jarkko Hietaniemi's modules for representing directed graphs,
 available from CPAN under modules/by-module/Graph/
@@ -233,12 +233,16 @@ available from CPAN under modules/by-module/Graph/
 The O'Reilly book which has a chapter on directed graphs,
 which is based around Jarkko's modules.
 
-=item Graph::Writer
+=item L<Graph::Writer>
 
 The base-class for Graph::Writer::daVinci
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/neilb/Graph-ReadWrite>
+
 =head1 AUTHOR
 
 Neil Bowers E<lt>neil@bowers.comE<gt>
